// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_JOBTYPELISTVIEW_H
#define TEST_JOBTYPELISTVIEW_H

//#include "jobtypelistview.h"
//#include "../third-party_stub/stub.h"
//#include <QObject>
//#include <QTest>
//#include <gtest/gtest.h>

//static QList<JobTypeInfo> jobtypelistview_stub_JobTypeInfos()
//{
//    QList<JobTypeInfo> infos;
//    infos.push_back(JobTypeInfo(1, "1", 0, "#000000"));
//    infos.push_back(JobTypeInfo(2, "2", 1, "#000000"));
//    infos.push_back(JobTypeInfo(3, "3", 2, "#000000"));

//    return infos;
//}


//class test_jobtypelistview: public::testing::Test
//{
//public:
//    test_jobtypelistview();

//    void SetUp()
//    {
//        Stub stub;
//        stub.set(ADDR(JobTypeInfoManager, getJobTypeList), jobtypelistview_stub_JobTypeInfos);
//        mWidget = new JobTypeListView();
//    }

//    void TearDown()
//    {
//        delete mWidget;
//        mWidget = nullptr;
//    }
//protected:
//    JobTypeListView *mWidget = nullptr;
//};

#endif // TEST_JOBTYPELISTVIEW_H
