// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef DDAVBASE_H
#define DDAVBASE_H

class DDavBase
{
public:
    DDavBase();
};

#endif // DDAVBASE_H