// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_cmonthdayitem.h"
#include <QPainter>
#include <QStyleOptionGraphicsItem>

//test_cmonthdayitem::test_cmonthdayitem()
//{

//}

//TEST_F(test_cmonthdayitem, paint_01)
//{
//    mItem->m_isFocus = true;
//    QPainter painter;
//    QStyleOptionGraphicsItem item;
//    mItem->paint(&painter, &item);
//}

//TEST_F(test_cmonthdayitem, paint_02)
//{
//    CMonthDayItem::m_LunarVisible = true;
//    QPainter painter;
//    QStyleOptionGraphicsItem item;
//    mItem->paint(&painter, &item);
//}

//TEST_F(test_cmonthdayitem, paint_03)
//{
//    CMonthDayItem::m_LunarVisible = true;
//    QPainter painter;
//    QStyleOptionGraphicsItem item;
//    mItem->setStatus(CMonthDayItem::H_REST);
//    EXPECT_EQ(mItem->m_DayStatus, CMonthDayItem::H_REST);
//    mItem->paint(&painter, &item);
//}

//TEST_F(test_cmonthdayitem, paint_04)
//{
//    CMonthDayItem::m_LunarVisible = true;
//    QPainter painter;
//    QStyleOptionGraphicsItem item;
//    mItem->setStatus(CMonthDayItem::H_WORK);
//    EXPECT_EQ(mItem->m_DayStatus, CMonthDayItem::H_WORK);
//    mItem->paint(&painter, &item);
//}
