// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_MONTHDAYVIEW_H
#define TEST_MONTHDAYVIEW_H

#include <QObject>
//#include "monthWidget/monthdayview.h"
//#include "gtest/gtest.h"

//class test_monthdayview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_monthdayview();
//    ~test_monthdayview();

//protected:
//    CMonthDayView *mMonthDayView = nullptr;
//    CMonthWidget *mMonthWidget = nullptr;
//    CMonthRect *mMonthRect = nullptr;
//};

#endif // TEST_MONTHDAYVIEW_H
