// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_scheduledatamanage.h"

//test_scheduledatamanage::test_scheduledatamanage()
//{
//    datamanage = new CScheduleDataManage();
//}

//test_scheduledatamanage::~test_scheduledatamanage()
//{
//    delete datamanage;
//}


////bool CScheduleDataManage::getSearchResult(QDate date)
//TEST_F(test_scheduledatamanage, getSearchResult)
//{
//    //QDate date(2020, 12, 01);
//    //datamanage->getSearchResult(date);
//}

////CScheduleDataManage *CScheduleDataManage::getScheduleDataManage()
//TEST_F(test_scheduledatamanage, getScheduleDataManage)
//{
//    datamanage->getScheduleDataManage();
//}

////QColor CScheduleDataManage::getSystemActiveColor()
//TEST_F(test_scheduledatamanage, getSystemActiveColor)
//{
//    datamanage->getSystemActiveColor();
//}

////int getTheme()
//TEST_F(test_scheduledatamanage, getTheme)
//{
//    datamanage->getTheme();
//}
