// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_lunarcalendarwidget.h"

//test_lunarcalendarwidget::test_lunarcalendarwidget()
//{

//}

//TEST_F(test_lunarcalendarwidget, setLunarYearText_001)
//{
//    mWidget->setLunarYearText("2023");
//    EXPECT_EQ(mWidget->lunarYearText(), "2023");
//}

//TEST_F(test_lunarcalendarwidget, minimumSizeHint_001)
//{
//    mWidget->minimumSizeHint();
//}
