// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_YEARSCHEDULEVIEW_H
#define TEST_YEARSCHEDULEVIEW_H

//#include "yearWidget/yearscheduleview.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_yearscheduleview : public QObject, public::testing::Test
//{
//public:
//    test_yearscheduleview();
//    ~test_yearscheduleview();
//    void SetUp() override;
//    void TearDown() override;

//protected:
//    CYearScheduleView *cYearScheduleView = nullptr;
//    CYearScheduleOutView *zYearScheduleOutView = nullptr;

//public:
//    QVector<ScheduleDataInfo> getScheduleDataInfo();
//    QVector<ScheduleDataInfo> getScheduleDateAndTitle();
//};

#endif // TEST_YEARSCHEDULEVIEW_H
