// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_JOBTYPECOMBOBOX_H
#define TEST_JOBTYPECOMBOBOX_H

//#include "jobtypecombobox.h"
//#include <QObject>
//#include <QTest>
//#include <gtest/gtest.h>

//class test_jobtypecombobox: public::testing::Test
//{
//public:
//    test_jobtypecombobox();

//    virtual void SetUp()
//    {
//        mWidget = new JobTypeComboBox();
//        mWidget->slotBtnAddItemClicked();
//    }

//    virtual void TearDown()
//    {
//        delete mWidget;
//        mWidget = nullptr;
//    }
//protected:
//    JobTypeComboBox *mWidget = nullptr;
//};

#endif // TEST_JOBTYPECOMBOBOX_H
