// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_MONTHVIEW_H
#define TEST_MONTHVIEW_H

#include <QObject>
#include "gtest/gtest.h"
//#include "monthWidget/monthview.h"

//class test_monthview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_monthview();
//    ~test_monthview();

//protected:
//    CMonthView *mMonthView = nullptr;
//};

#endif // TEST_MONTHVIEW_H
