// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_colorslider.h"

//test_colorslider::test_colorslider(QObject *parent) : QObject(parent)
//{

//}

//TEST_F(test_colorslider, getColor_001)
//{
//    EXPECT_EQ(mWidget->getColor(0, 0, 0).name(), "#000000");
//    EXPECT_EQ(mWidget->getColor(1, 0.5, 0.5).name(), "#3f7e7f");;
//    EXPECT_EQ(mWidget->getColor(1, 0.2, 0.5).name(), "#667f7f");
//    EXPECT_EQ(mWidget->getColor(1, 0.1, 0.9).name(), "#cee5e5");
//    EXPECT_EQ(mWidget->getColor(1, 0.3, 0.4).name(), "#476566");
//    EXPECT_EQ(mWidget->getColor(2, 0.5, 0.5).name(), "#3f7d7f");
//    EXPECT_EQ(mWidget->getColor(0.5, 0.5, 0.5).name(), "#3f7e7f");
//    EXPECT_EQ(mWidget->getColor(5, 0.5, 0.5).name(), "#3f7a7f");
//    EXPECT_EQ(mWidget->getColor(1, 0.5, 0.5).name(), "#3f7e7f");
//    EXPECT_EQ(mWidget->getColor(10, 0, 0).name(), "#000000");
//    EXPECT_EQ(mWidget->getColor(60, 0, 0).name(), "#000000");
//    EXPECT_EQ(mWidget->getColor(71, 0, 0).name(), "#000000");
//}

//TEST_F(test_colorslider, paintEvent_001)
//{
//    QPaintEvent *e = new QPaintEvent(QRect());
//    mWidget->paintEvent(e);
//    delete e;
//}
