// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CMONTHDAYITEM_H
#define TEST_CMONTHDAYITEM_H

//#include "graphicsItem/cmonthdayitem.h"
//#include <QObject>
//#include <gtest/gtest.h>

//class test_cmonthdayitem: public::testing::Test
//{
//public:
//    test_cmonthdayitem();

//    virtual void SetUp()
//    {
//        mItem = new CMonthDayItem();
//    }

//    virtual void TearDown()
//    {
//        delete mItem;
//        mItem = nullptr;
//    }
//protected:
//    CMonthDayItem *mItem = nullptr;
//};

#endif // TEST_CMONTHDAYITEM_H
