// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_ckeypressprxy.h"
//#include "ckeyleftdeal.h"

//test_CKeyPressPrxy::test_CKeyPressPrxy()
//{
//    keyPressPrxy = QSharedPointer<CKeyPressPrxy>(new CKeyPressPrxy);
//}

//TEST_F(test_CKeyPressPrxy, keyPressDeal_NoEvent)
//{
//    ASSERT_FALSE(keyPressPrxy->keyPressDeal(Qt::Key_Tab));
//}

//TEST_F(test_CKeyPressPrxy, keyPressDeal)
//{
//    keyPressPrxy->addkeyPressDeal(new CKeyLeftDeal());
//    ASSERT_FALSE(keyPressPrxy->keyPressDeal(Qt::Key_Left));
//}

//TEST_F(test_CKeyPressPrxy, removeDeal)
//{
//    CKeyLeftDeal *leftDeal = new CKeyLeftDeal();
//    keyPressPrxy->addkeyPressDeal(leftDeal);
//    keyPressPrxy->removeDeal(leftDeal);
//    ASSERT_FALSE(keyPressPrxy->keyPressDeal(Qt::Key_Left));
//}
