// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CALLDAYSCHEDULEITEM_H
#define TEST_CALLDAYSCHEDULEITEM_H

//#include "gtest/gtest.h"
//#include "graphicsItem/calldayscheduleitem.h"

//#include <QObject>

//class test_CAlldayscheduleitem : public QObject
//    , public ::testing::Test
//{
//    Q_OBJECT
//public:
//    test_CAlldayscheduleitem();
//    void SetUp() override;
//    void TearDown() override;
//signals:

//public slots:
//public:
//    CAllDayScheduleItem *m_allItem;
//    QRectF m_rectF;
//};

#endif // TEST_CALLDAYSCHEDULEITEM_H
