// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_YEARWINDOW_H
#define TEST_YEARWINDOW_H

//#include "yearWidget/yearwindow.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_yearwindow : public QObject
//    , public ::testing::Test
//{
//public:
//    test_yearwindow();
//    ~test_yearwindow();

//protected:
//    CYearWindow *mYearWindow = nullptr;
//    CalendarDateDataManager *dateaManger = nullptr;
//};

#endif // TEST_YEARWINDOW_H
