// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CSCENEBACKGROUNDITEM_H
#define TEST_CSCENEBACKGROUNDITEM_H

//#include "graphicsItem/cscenebackgrounditem.h"
//#include <gtest/gtest.h>
//#include <../third-party_stub/stub.h>
//#include <QObject>
//#include <QGraphicsScene>

//class test_cscenebackgrounditem: public::testing::Test
//{
//public:
//    test_cscenebackgrounditem();

//    virtual void SetUp()
//    {
//        mItem = new CSceneBackgroundItem(CSceneBackgroundItem::OnMonthView);
//        mFocusItem  = new CFocusItem();
//        mScene = new QGraphicsScene();
//        mScene->addItem(mItem);
//        mScene->addItem(mFocusItem);
//        mItem->m_item.append(mFocusItem);
//        mItem->m_item.append(mFocusItem);
//    }

//    virtual void TearDown()
//    {
//        delete mItem;
//        mItem = nullptr;
//        delete mFocusItem;
//        delete mScene;
//    }
//protected:
//    CSceneBackgroundItem *mItem = nullptr;
//    CFocusItem *mFocusItem = nullptr;
//    QGraphicsScene *mScene = nullptr;
//};

#endif // TEST_CSCENEBACKGROUNDITEM_H
