// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_WEEKHEADVIEW_H
#define TEST_WEEKHEADVIEW_H

//#include "weekWidget/weekheadview.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_weekheadview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_weekheadview();
//    ~test_weekheadview();

//protected:
//    CWeekHeadView *mWeekHeadView = nullptr;
//};

#endif // TEST_WEEKHEADVIEW_H
