// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_MONTHSCHEDULEVIEW_H
#define TEST_MONTHSCHEDULEVIEW_H

#include <QObject>
//#include "monthWidget/monthscheduleview.h"
//#include "graphicsItem/cmonthscheduleitem.h"
//#include "graphicsItem/cmonthschedulenumitem.h"
//#include "gtest/gtest.h"

//class test_monthscheduleview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_monthscheduleview();
//    ~test_monthscheduleview();

//protected:
//    CMonthScheduleView *mMonthScheduleView = nullptr;
//    CMonthScheduleItem *mMonthScheduleWidgetItem = nullptr;
//    CWeekScheduleView *mWeekScheduleView = nullptr;
//    CMonthScheduleNumItem *mMonthScheduleNumButton = nullptr;
//    QGraphicsScene *m_scene = nullptr;
//};

#endif // TEST_MONTHSCHEDULEVIEW_H
