// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_labelwidget.h"
//#include "../third-party_stub/stub.h"

//test_labelwidget::test_labelwidget()
//{

//}

//TEST_F(test_labelwidget, paintEvent_001)
//{
//    QPaintEvent e(QRect(0, 0, 0, 0));
//    mWidget->paintEvent(&e);
//}
