// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CALLDAYKEYLEFTDEAL_H
#define TEST_CALLDAYKEYLEFTDEAL_H

#include <QObject>
#include <QWidget>

class test_CAllDayKeyLeftDeal : public QObject
{
    Q_OBJECT
public:
    explicit test_CAllDayKeyLeftDeal(QObject *parent = nullptr);

signals:

public slots:
};

#endif // TEST_CALLDAYKEYLEFTDEAL_H