// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_cradiobutton.h"

//test_cradiobutton::test_cradiobutton()
//{

//}

//TEST_F(test_cradiobutton, setColor_001)
//{
//    QColor color("#000000");
//    mWidget->setColor(color);
//    EXPECT_EQ(mWidget->getColor(), color);
//}

//TEST_F(test_cradiobutton, paintEvent_001)
//{
//    QColor color("#000000");
//    mWidget->setColor(color);
//    mWidget->setChecked(true);
//    QPaintEvent *e = new QPaintEvent(QRect());
//    mWidget->paintEvent(e);
//    delete e;
//}

//TEST_F(test_cradiobutton, paintEvent_002)
//{
//    QColor color("#000000");
//    mWidget->setColor(color);
//    mWidget->setChecked(false);
//    QPaintEvent *e = new QPaintEvent(QRect());
//    mWidget->paintEvent(e);
//    delete e;
//}
