// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef SERVICE_STUB_H
#define SERVICE_STUB_H

#include "../third-party_stub/stub.h"

void qDBusMessage_type_Stub(Stub &stub);

void qDBusAbstractInterface_callWithArgumentList_stub(Stub &stub);

#endif // SERVICE_STUB_H
