// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_COLORLABEL_H
#define TEST_COLORLABEL_H

//#include <colorWidget/colorlabel.h>
//#include <QObject>
//#include <QTest>
//#include <gtest/gtest.h>

//class test_colorlabel : public QObject, public::testing::Test
//{
//    Q_OBJECT
//public:
//    explicit test_colorlabel(QObject *parent = nullptr);

//signals:

//public slots:
//};

#endif // TEST_COLORLABEL_H
