// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_cscheduleitem.h"
#include <QPainter>

//test_cscheduleitem::test_cscheduleitem()
//{

//}

//TEST_F(test_cscheduleitem, setData_01)
//{
//    mItem->setData(ScheduleDataInfo(), QDate(), 2);
//    EXPECT_EQ(mItem->m_totalNum, 2);
//}

//TEST_F(test_cscheduleitem, hasSelectSchedule_01)
//{
//    ScheduleDataInfo info;
//    mItem->setData(info, QDate(), 2);
//    EXPECT_TRUE(mItem->hasSelectSchedule(info));
//}

//TEST_F(test_cscheduleitem, splitTexte_01)
//{
//    QFont font;
//    QStringList strList;
//    QFontMetrics metrics(font);
//    ScheduleDataInfo info;
//    mItem->splitText(font, 20, 10, "123", strList, metrics);
//}

//TEST_F(test_cscheduleitem, paintBackground_01)
//{
//    QPainter painter;
//    QRectF rect;
//    mItem->m_vHoverflag = true;
//    mItem->m_vSelectflag = false;
//    mItem->paintBackground(&painter, rect);
//}

//TEST_F(test_cscheduleitem, paintBackground_02)
//{
//    QPainter painter;
//    QRectF rect;
//    mItem->m_vHoverflag = true;
//    mItem->m_vSelectflag = true;
//    mItem->paintBackground(&painter, rect);
//}
