// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_dayhuangliview.h"

//test_dayhuangliview::test_dayhuangliview()
//{
//    mDayHuangLiLabel = new CDayHuangLiLabel();
//}

//test_dayhuangliview::~test_dayhuangliview()
//{
//    delete mDayHuangLiLabel;
//    mDayHuangLiLabel = nullptr;
//}

////void CDayHuangLiLabel::setbackgroundColor(QColor backgroundColor)
//TEST_F(test_dayhuangliview, setbackgroundColor)
//{
//    mDayHuangLiLabel->setbackgroundColor(QColor(100, 100, 255));
//}

////void CDayHuangLiLabel::setTextInfo(QColor tcolor, QFont font)
//TEST_F(test_dayhuangliview, setTextInfo)
//{
//    mDayHuangLiLabel->setTextInfo(QColor(100, 100, 255), QFont());
//}

////void CDayHuangLiLabel::setHuangLiText(QStringList vhuangli, int type)
//TEST_F(test_dayhuangliview, setHuangLiText)
//{
//    QStringList strlist("嫁娶 入土");
//    mDayHuangLiLabel->setHuangLiText(strlist, 1);
//    QStringList strlist1("");
//    mDayHuangLiLabel->setHuangLiText(strlist1, 2);
//}

//TEST_F(test_dayhuangliview, getPixmap)
//{
//    QStringList strlist("嫁娶 入土");
//    mDayHuangLiLabel->setHuangLiText(strlist, 1);
//    mDayHuangLiLabel->setbackgroundColor(QColor(100, 100, 255));
//    mDayHuangLiLabel->setFixedSize(200, 50);
//    QPixmap pixmap(mDayHuangLiLabel->size());
//    mDayHuangLiLabel->render(&pixmap);
//}
