// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef DATAENCRYPT_H
#define DATAENCRYPT_H

#include <QByteArray>
#include <QString>
//#include <openssl/aes.h>

//const QString aesCbcKey = "kjX3yBgJCaFHszod";

//class DataEncrypt
//{
//public:
//    static QByteArray aesCbcEncrypt(const QByteArray &data, const QByteArray &key,
//                                    const QByteArray &initialVector);
//    static QByteArray aesCbcDecrypt(const QByteArray &data, const QByteArray &key,
//                                    const QByteArray &initialVector);

//    static QByteArray aesCfb128Encrypt(const QByteArray &data, const QByteArray &key,
//                                    const QByteArray &initialVector);
//    static QByteArray aesCfb128Decrypt(const QByteArray &data, const QByteArray &key,
//                                    const QByteArray &initialVector);

//private:
//    static QByteArray aesCbcEncrypt(const QByteArray &data, const AES_KEY &key,
//                                    const QByteArray &initialVector, bool isEncrypt);

//    static QByteArray aesCfb128Encrypt(const QByteArray &data, const AES_KEY &key,
//                                       const QByteArray &initialVector, bool isEncrypt);
//};

#endif // DATAENCRYPT_H
