// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_GRAPHICSSCENE_H
#define TEST_GRAPHICSSCENE_H

//#include "gtest/gtest.h"
//#include "cgraphicsscene.h"

//#include <QObject>

//class test_graphicsscene : public QObject
//    , public ::testing::Test
//{
//    Q_OBJECT
//public:
//    test_graphicsscene();

//    void SetUp() override;
//    void TearDown() override;
//signals:

//public slots:
//public:
//    CGraphicsScene *m_Scene = nullptr;
//};

#endif // TEST_GRAPHICSSCENE_H
