// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_DAYHUANGLIVIEW_H
#define TEST_DAYHUANGLIVIEW_H

//#include <QObject>
//#include <dayWidget/dayhuangliview.h>
//#include <gtest/gtest.h>

//class test_dayhuangliview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_dayhuangliview();
//    ~test_dayhuangliview();

//protected:
//    CDayHuangLiLabel *mDayHuangLiLabel = nullptr;
//};

#endif // TEST_DAYHUANGLIVIEW_H
