// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CALENDARDATEDATAMANAGE_H
#define TEST_CALENDARDATEDATAMANAGE_H

//#include "calendardatedatamanage.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_calendardatedatamanage : public QObject, public::testing::Test
//{
//public:
//    test_calendardatedatamanage();
//    void SetUp() override;
//    void TearDown() override;

//protected:
//    CalendarDateDataManager *calendarDateDataManager = nullptr;
//};

#endif // TEST_CALENDARDATEDATAMANAGE_H
