// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_MONTHGRAPHVIEW_H
#define TEST_MONTHGRAPHVIEW_H

//#include "monthgraphiview.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_monthgraphiview : public QObject, public::testing::Test
//{
//public:
//    test_monthgraphiview();
//    ~test_monthgraphiview();
//protected:
//    CMonthGraphicsview *cMonthGraphiview = nullptr;
//};

#endif // TEST_MONTHGRAPHVIEW_H
