// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TESTSCHEDULEDATA_H
#define TESTSCHEDULEDATA_H

//#include "src/scheduledatainfo.h"

//#include <QVector>

//class TestScheduleData
//{
//public:
//    TestScheduleData();
//};

//namespace TestDataInfo {
//QVector<ScheduleDataInfo> getScheduleItemDInfo();
//}

#endif // TESTSCHEDULEDATA_H
