// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_daywindow.h"

//test_dayWindow::test_dayWindow()
//{
//}

//void test_dayWindow::SetUp()
//{
//    QDateTime currentTime = QDateTime::currentDateTime();
//    m_dayWindow = new CDayWindow();
//    m_dayWindow->setCurrentDateTime(currentTime);
//    m_dayWindow->setSelectDate(currentTime.date());
//}

//void test_dayWindow::TearDown()
//{
//    delete m_dayWindow;
//    m_dayWindow = nullptr;
//}

////测试paintevent
//TEST_F(test_dayWindow, getPixmap)
//{
//    m_dayWindow->setFixedSize(800, 600);
//    QPixmap pixmap(m_dayWindow->size());
//    m_dayWindow->render(&pixmap);
//}

////setTheme
//TEST_F(test_dayWindow, setTheme)
//{
//    m_dayWindow->setTheMe(0);
//    m_dayWindow->setTheMe(1);
//    m_dayWindow->setTheMe(2);
//}

////setSearchWFlag
//TEST_F(test_dayWindow, setSearchWFlag)
//{
//    m_dayWindow->setSearchWFlag(false);
//}

////slotChangeSelectDate
//TEST_F(test_dayWindow, slotChangeSelectDate)
//{
//    m_dayWindow->slotChangeSelectDate(m_dayWindow->getSelectDate());
//}

////slotSwitchPrePage
//TEST_F(test_dayWindow, slotSwitchPrePage)
//{
//    m_dayWindow->slotSwitchPrePage();
//}

////slotSwitchNextPage
//TEST_F(test_dayWindow, slotSwitchNextPage)
//{
//    m_dayWindow->slotSwitchNextPage();
//}
