// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CKEYPRESSPRXY_H
#define TEST_CKEYPRESSPRXY_H

//#include "configsettings.h"
//#include "gtest/gtest.h"
//#include "ckeypressprxy.h"

//#include <QObject>
//#include <QSharedPointer>

//class test_CKeyPressPrxy : public QObject
//    , public ::testing::Test
//{
//    Q_OBJECT
//public:
//    test_CKeyPressPrxy();

//signals:

//public slots:

//public:
//    QSharedPointer<CKeyPressPrxy> keyPressPrxy;
//};

#endif // TEST_CKEYPRESSPRXY_H
