// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_SCHEDULEITEM_H
#define TEST_SCHEDULEITEM_H

//#include <QObject>
//#include <gtest/gtest.h>
//#include "graphicsItem/scheduleitem.h"

//class test_scheduleitem : public ::QObject
//    , public ::testing::Test
//{
//public:
//    test_scheduleitem();
//    ~test_scheduleitem();

//protected:
//    CScheduleItem *mScheduleItem = nullptr;
//};

#endif // TEST_SCHEDULEITEM_H
