// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_DRAGINFOITEM_H
#define TEST_DRAGINFOITEM_H

//#include "graphicsItem/scheduleitem.h"
//#include <gtest/gtest.h>
//#include <../third-party_stub/stub.h>
//#include <QObject>
//#include <QGraphicsScene>

//class test_cscheduleitem: public::testing::Test
//{
//public:
//    test_cscheduleitem();

//    virtual void SetUp()
//    {
//        QRectF rect(0, 0, 100, 100);
//        mItem = new CScheduleItem(rect);
//    }

//    virtual void TearDown()
//    {
//        delete mItem;
//        mItem = nullptr;
//    }
//protected:
//    CScheduleItem *mItem = nullptr;
//};

#endif // TEST_DRAGINFOITEM_H
