// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_weekview.h"

//int getWeekNumOfYear(const QDate &date)
//{
//    Q_UNUSED(date);
//    return 4;
//}

//test_weekview::test_weekview()
//{
//    mWeekView = new CWeekView(&getWeekNumOfYear);
//}

//test_weekview::~test_weekview()
//{
//    delete mWeekView;
//    mWeekView = nullptr;
//}

////void CWeekView::setSelectDate(const QDate date)
//TEST_F(test_weekview, setSelectDate)
//{
//    mWeekView->setSelectDate(QDate::currentDate());
//}

////void CWeekView::setCurrent(const QDateTime &dateTime)
//TEST_F(test_weekview, setCurrent)
//{
//    mWeekView->setCurrent(QDateTime::currentDateTime());
//}

////void CWeekView::setTheMe(int type)
//TEST_F(test_weekview, setTheMe)
//{
//    mWeekView->setTheMe(1);
//    mWeekView->setTheMe(2);
//}

//TEST_F(test_weekview, getPixmap)
//{
//    mWeekView->setSelectDate(QDate::currentDate());
//    mWeekView->setFixedSize(600, 50);
//    QPixmap pixmap(mWeekView->size());
//    mWeekView->render(&pixmap);
//}
