// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_cmonthschedulenumitem.h"
#include <QPainter>
#include <QStyleOptionGraphicsItem>

//test_cmonthschedulenumItem::test_cmonthschedulenumItem()
//{

//}

//TEST_F(test_cmonthschedulenumItem, setColor_01)
//{
//    QColor color1("#000000");
//    QColor color2("#111111");
//    mItem->setColor(color1, color2);
//    EXPECT_EQ(mItem->m_color1, color1);
//    EXPECT_EQ(mItem->m_color2, color2);
//}

//TEST_F(test_cmonthschedulenumItem, setText_01)
//{
//    QColor color("#000000");
//    mItem->setText(color, QFont());
//    EXPECT_EQ(mItem->m_textcolor, color);
//}

//TEST_F(test_cmonthschedulenumItem, setSizeType_01)
//{
//    QColor color("#000000");
//    mItem->setSizeType(DFontSizeManager::T5);
//    EXPECT_EQ(mItem->m_SizeType, DFontSizeManager::T5);
//}

//TEST_F(test_cmonthschedulenumItem, setData_01)
//{
//    QColor color("#000000");
//    mItem->setData(4);
//    EXPECT_EQ(mItem->m_num, 4);
//}

//TEST_F(test_cmonthschedulenumItem, paint_01)
//{
//    mItem->m_isFocus = true;
//    QPainter painter;
//    QStyleOptionGraphicsItem item;
//    mItem->paint(&painter, &item);
//}
