// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_DAYWINDOW_H
#define TEST_DAYWINDOW_H

//#include "gtest/gtest.h"
//#include "dayWidget/daywindow.h"

//#include <QObject>

//class test_dayWindow : public QObject
//    , public ::testing::Test
//{
//    Q_OBJECT
//public:
//    test_dayWindow();
//    void SetUp() override;
//    void TearDown() override;
//signals:

//public slots:
//public:
//    CDayWindow *m_dayWindow;
//};

#endif // TEST_DAYWINDOW_H
