// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_CWEEKDAYBACKGROUNDITEM_H
#define TEST_CWEEKDAYBACKGROUNDITEM_H

//#include "graphicsItem/cweekdaybackgrounditem.h"
//#include "gtest/gtest.h"

//#include <QObject>

//class test_CWeekDayBackgroundItem : public QObject
//    , public testing::Test
//{
//    Q_OBJECT
//public:
//    test_CWeekDayBackgroundItem();
//    // Sets up the test fixture.
//    void SetUp() override;

//    // Tears down the test fixture.
//    void TearDown() override;

//signals:

//public slots:

//public:
//    CWeekDayBackgroundItem *m_weekItem;
//};

#endif // TEST_CWEEKDAYBACKGROUNDITEM_H
