// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "test_cscenebackgrounditem.h"

//test_cscenebackgrounditem::test_cscenebackgrounditem()
//{

//}

//TEST_F(test_cscenebackgrounditem, setNextItemFocusAndGetNextItem_01)
//{
//    mItem->m_showItemIndex = 0;
//    mItem->setNextItemFocusAndGetNextItem();
//}

//TEST_F(test_cscenebackgrounditem, setNextItemFocusAndGetNextItem_02)
//{
//    mItem->m_showItemIndex = 1;
//    mItem->setNextItemFocusAndGetNextItem();
//}

//TEST_F(test_cscenebackgrounditem, setNextItemFocusAndGetNextItem_03)
//{
//    mItem->m_showItemIndex = -1;
//    mItem->m_isFocus = true;
//    mItem->setNextItemFocusAndGetNextItem();
//}

//TEST_F(test_cscenebackgrounditem, setItemFocus_01)
//{
//    mItem->m_showItemIndex = -1;
//    mItem->setItemFocus(true);
//}

//TEST_F(test_cscenebackgrounditem, setItemFocus_02)
//{
//    mItem->m_showItemIndex = 1;
//    mItem->setItemFocus(true);
//}

//TEST_F(test_cscenebackgrounditem, initState_01)
//{
//    mItem->m_showItemIndex = 1;
//    mItem->initState();
//}

//TEST_F(test_cscenebackgrounditem, updateCurrentItemShow_01)
//{
//    mItem->m_showItemIndex = 1;
//    mItem->updateCurrentItemShow();
//}
