// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_SCHEDULECOORMANAGE_H
#define TEST_SCHEDULECOORMANAGE_H

//#include "schedulecoormanage.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_schedulecoormanage : public QObject, public::testing::Test
//{
//public:
//    test_schedulecoormanage();
//    ~test_schedulecoormanage();
//protected:
//    CScheduleCoorManage *cScheduleCoorManage = nullptr;
//};

#endif // TEST_SCHEDULECOORMANAGE_H
