// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TESTMAINWINDOWGUI_H
#define TESTMAINWINDOWGUI_H

//#include "calendarmainwindow.h"
//#include "gtest/gtest.h"
//#include "../third-party_stub/stub.h"

//#include <QtTest/QTest>
//#include <QObject>

//class testMainWindowGUI : public QObject
//    , public ::testing::Test
//{
//public:
//    testMainWindowGUI();
//    void SetUp() override;
//    void TearDown() override;

//public:
//    Stub stub;
//};

#endif // TESTMAINWINDOWGUI_H
