// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_WEEKVIEW_H
#define TEST_WEEKVIEW_H

//#include "weekWidget/weekview.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_weekview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_weekview();
//    ~test_weekview();

//protected:
//    CWeekView *mWeekView = nullptr;
//};

#endif // TEST_WEEKVIEW_H
