// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef TEST_YEARVIEW_H
#define TEST_YEARVIEW_H

//#include "yearWidget/yearview.h"
//#include "gtest/gtest.h"
//#include <QObject>

//class test_yearview : public QObject
//    , public ::testing::Test
//{
//public:
//    test_yearview();
//    ~test_yearview();
//    void SetUp() override;
//    void TearDown() override;

//protected:
//    CYearView *cYearView = nullptr;
//};

#endif // TEST_YEARVIEW_H
